summaryrefslogtreecommitdiff
path: root/lib/scripts/script.js
diff options
context:
space:
mode:
Diffstat (limited to 'lib/scripts/script.js')
-rw-r--r--lib/scripts/script.js20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/scripts/script.js b/lib/scripts/script.js
index d621232ce..834f0f4a4 100644
--- a/lib/scripts/script.js
+++ b/lib/scripts/script.js
@@ -132,7 +132,7 @@ function prependChild(parent,element) {
function showLoadBar(){
if(document.getElementById){
document.write('<img src="'+DOKU_BASE+'lib/images/loading.gif" '+
- 'width="150" height="12" id="loading" />');
+ 'width="150" height="12" id="dw__loading" />');
}
}
@@ -143,7 +143,7 @@ function showLoadBar(){
*/
function hideLoadBar(){
if(document.getElementById){
- $('loading').style.display="none";
+ $('dw__loading').style.display="none";
}
}
@@ -153,7 +153,7 @@ function hideLoadBar(){
* @see http://www.alexking.org/index.php?content=software/javascript/content.php
*/
function mediaSelect(file){
- opener.insertTags('wikitext','{{'+file+'|','}}',file);
+ opener.insertTags('wiki__text','{{'+file+'|','}}',file);
window.close();
}
@@ -296,34 +296,34 @@ var currentFootnote = 0;
function fnt(id, e, evt) {
if (currentFootnote && id != currentFootnote) {
- domTT_close($('insitu-fn'+currentFootnote));
+ domTT_close($('insitu__fn'+currentFootnote));
}
// does the footnote tooltip already exist?
- var fnote = $('insitu-fn'+id);
+ var fnote = $('insitu__fn'+id);
var footnote;
if (!fnote) {
// if not create it...
// locate the footnote anchor element
- var a = $( "fn"+id );
+ var a = $( "fn__"+id );
if (!a){ return; }
// anchor parent is the footnote container, get its innerHTML
footnote = new String (a.parentNode.innerHTML);
// strip the leading footnote anchors and their comma separators
- footnote = footnote.replace(/<a\s.*?href=\".*\#fnt\d+\".*?<\/a>/gi, '');
+ footnote = footnote.replace(/<a\s.*?href=\".*\#fnt__\d+\".*?<\/a>/gi, '');
footnote = footnote.replace(/^\s+(,\s+)+/,'');
- // prefix ids on any elements with "insitu-" to ensure they remain unique
- footnote = footnote.replace(/\bid=\"(.*?)\"/gi,'id="insitu-$1');
+ // prefix ids on any elements with "insitu__" to ensure they remain unique
+ footnote = footnote.replace(/\bid=\"(.*?)\"/gi,'id="insitu__$1');
} else {
footnote = new String(fnt.innerHTML);
}
// activate the tooltip
- domTT_activate(e, evt, 'content', footnote, 'type', 'velcro', 'id', 'insitu-fn'+id, 'styleClass', 'insitu-footnote JSpopup', 'maxWidth', document.body.offsetWidth*0.4);
+ domTT_activate(e, evt, 'content', footnote, 'type', 'velcro', 'id', 'insitu__fn'+id, 'styleClass', 'insitu-footnote JSpopup', 'maxWidth', document.body.offsetWidth*0.4);
currentFootnote = id;
}